@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright 2008-2015 Calculate Ltd. http://www.calculate-linux.org
+# Copyright 2008-2016 Mir Calculate. http://www.calculate-linux.org
 #
 #  Licensed under the Apache License, Version 2.0 (the "License");
 #  you may not use this file except in compliance with the License.
@@ -14,9 +14,10 @@
 #  See the License for the specific language governing permissions and
 #  limitations under the License.
 
+
 import logging
 import logging.handlers
-import cl_overriding
+from . import cl_overriding
 
 
 class log:
@@ -41,7 +42,7 @@ class log:
                 handler = logging.handlers.RotatingFileHandler(
                     self.filename, maxBytes=self.maxBytes,
                     backupCount=self.backupCount)
-            except Exception, e:
+            except Exception as e:
                 cl_overriding.printERROR("logging -  %s - %s" %
                                          (self.programName, str(e)))
                 return False
