@@ -15,9 +15,9 @@
 #  limitations under the License.
 
 import re
-from calculate.lib.cl_template import blocText
-from calculate.lib.cl_xml import xmlDoc
-from calculate.lib.format.samba import samba
+from ..cl_template import blocText
+from ..cl_xml import xmlDoc
+from .samba import samba
 
 
 class ldap(samba):
@@ -28,10 +28,9 @@ class ldap(samba):
     configName = "ldap"
     configVersion = "0.1"
     # Регулярное выражение для заголовка области
-    reHeader = re.compile("^[\t ]*(access|syncrepl)[^\n]+\n?")
+    reHeader = re.compile("^[\t ]*(!?access|syncrepl)[^\n]+\n?")
     # Регулярное выражения для области
-    reArea = re.compile("([\t ]*(access|syncrepl)[^\n]+\
-\n([\t ]+[^\n]+\n?)+)", re.M | re.S)
+    reArea = re.compile("([\t ]*(!?access|syncrepl)[^\n]+\n([\t ]+[^\n]+\n?)+)", re.M | re.S)
     reComment = re.compile("\s*%s.*" % _comment)
     # разделитель между переменной и значением переменной
     reSeparator = re.compile("\s+")
@@ -161,7 +160,7 @@ class ldap(samba):
                             docObj.setActionField(xmlField, "drop")
                         elif f.name[0] == "+":
                             # Добавляем уникальное поле
-                            xmlField.setAttribute("type", "seplist")
+                            xmlField.set("type", "seplist")
                             docObj.setActionField(xmlField, "join")
                     else:
                         docObj.createField("var", [f.br.replace("\n", "")],
@@ -175,11 +174,11 @@ class ldap(samba):
                 area = docObj.createArea()
                 if areaAction:
                     docObj.setActionArea(area, areaAction)
-                rootNode.appendChild(area)
+                rootNode.append(area)
             else:
                 fieldsNodes = docObj.tmpFields.getFields()
                 for fieldNode in fieldsNodes:
-                    rootNode.appendChild(fieldNode)
+                    rootNode.append(fieldNode)
                 docObj.clearTmpFields()
             z += 1
         return docObj
